@@ -58,7 +58,9 @@ LOGGER = get_logger(__name__)
 class E2ETest:
     # Disable pylint check fo unitary E2E test class
     # pylint: disable=too-many-instance-attributes
-    def __init__(self, image_name: str, variant: str = "", interactive_mode: bool = False):
+    def __init__(
+        self, image_name: str, variant: str = "", interactive_mode: bool = False
+    ):
         """E2ETest main class.
 
         Args:
@@ -197,8 +199,10 @@ class E2ETest:
         default_run_cmd = f"docker run {'-it' if self.interactive_mode else ''} --volumes-from e2e --name job -e"
 
         LOGGER.info("Running container...")
-        run_cmd = f"{default_run_cmd} 'UP42_TASK_PARAMETERS={json.dumps(self.parameters)}'" \
-                  f" {self.additional_env if self.additional_env else ''} {self.image_name}"
+        run_cmd = (
+            f"{default_run_cmd} 'UP42_TASK_PARAMETERS={json.dumps(self.parameters)}'"
+            f" {self.additional_env if self.additional_env else ''} {self.image_name}"
+        )
 
         start = timeit.default_timer()
         self.run_subprocess(run_cmd, exit_code=self.expected_exit_code)
